@@ -28,6 +28,7 @@ public class ParsePushPlugin extends CordovaPlugin {
    private static final String ACTION_UNSUBSCRIBE = "unsubscribe";
    private static final String ACTION_REGISTER_CALLBACK = "registerCallback";
    private static final String ACTION_REGISTER_FOR_PN = "register";
+   public static final String ACTION_RESET_BADGE = "resetBadge";
 
    private static CallbackContext gEventCallback = null;
    private static Queue<PluginResult> pnQueue = new LinkedList();
@@ -69,6 +70,10 @@ public class ParsePushPlugin extends CordovaPlugin {
          this.unsubscribe(args.getString(0), callbackContext);
          return true;
       }
+      if (action.equals(ACTION_RESET_BADGE)) {
+           ParsePushPluginReceiver.resetBadge(this.cordova.getActivity().getApplicationContext());
+           return true;
+       }
       if (action.equals(ACTION_REGISTER_FOR_PN)) {
          this.registerDeviceForPN(callbackContext);
          return true;
