@@ -104,6 +104,16 @@
     [self.commandDelegate sendPluginResult:pluginResult callbackId:command.callbackId];
 }
 
+- (void)resetBadge:(CDVInvokedUrlCommand *)command {
+     CDVPluginResult* pluginResult = nil;
+     PFInstallation *currentInstallation = [PFInstallation currentInstallation];
+     currentInstallation.badge = 0;
+
+     [currentInstallation saveInBackground];
+     pluginResult = [CDVPluginResult resultWithStatus:CDVCommandStatus_OK];
+     [self.commandDelegate sendPluginResult:pluginResult callbackId:command.callbackId];
+}
+
 
 - (void)registerForPN {
     //
