@@ -66,6 +66,10 @@ var ParsePushPlugin = {
    unsubscribe: function(channel, successCb, errorCb) {
       cordova.exec(successCb, errorCb, serviceName, 'unsubscribe', [ channel ]);
    },
+   
+   resetBadge: function(successCb, errorCb) {
+       cordova.exec(successCb, errorCb, serviceName, 'resetBadge', []);
+   },
 
    register: function(successCb, errorCb) {
       cordova.exec(successCb, errorCb, serviceName, 'register', []);
